package com.ruoyi.system.controller;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

import com.ruoyi.common.utils.StringUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.TStallInfo;
import com.ruoyi.system.service.ITStallInfoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 【请填写功能名称】Controller
 * 
 * @author ruoyi
 * @date 2020-08-30
 */
@RestController
@RequestMapping("/system/info")
public class TStallInfoController extends BaseController
{
    @Autowired
    private ITStallInfoService tStallInfoService;

    /**
     * 查询【摊位信息】列表
     */
    @PreAuthorize("@ss.hasPermi('system:info:list')")
    @GetMapping("/list")
    public TableDataInfo list(TStallInfo tStallInfo)
    {
        startPage();
        List<TStallInfo> list = tStallInfoService.selectTStallInfoList(tStallInfo);
        return getDataTable(list);
    }

    /**
     * 导出【摊位信息】列表
     */
    @PreAuthorize("@ss.hasPermi('system:info:export')")
    @Log(title = "【摊位信息】", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TStallInfo tStallInfo)
    {
        List<TStallInfo> list = tStallInfoService.selectTStallInfoList(tStallInfo);
        ExcelUtil<TStallInfo> util = new ExcelUtil<TStallInfo>(TStallInfo.class);
        return util.exportExcel(list, "info");
    }

    /**
     * 获取【摊位信息】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:info:query')")
    @GetMapping(value = "/byId")
    public AjaxResult getInfo(String id)
    {
        return AjaxResult.success(tStallInfoService.selectTStallInfoById(id));
    }

    /**
     * 获取【摊位信息】详细信息
     */

    @RequestMapping(value = "/byStallNumber")
    public AjaxResult getInfoByStallNumber(String stallNumber)
    {
        if (StringUtils.isEmpty(stallNumber)){
            return AjaxResult.error("摊位号不能为空");
        }
        TStallInfo tStallInfo = new TStallInfo();
        tStallInfo.setStallNumber(stallNumber);
        List<TStallInfo> info = tStallInfoService.selectTStallInfoList(tStallInfo);
        if (info == null || info.size() < 1){
            return AjaxResult.error("没有该摊位信息");
        }
        SimpleDateFormat df = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        info.get(0).setLandTime(df.format(new Date()));
        return AjaxResult.success(info);
    }


    /**
     * 新增【摊位信息】
     */
    @PreAuthorize("@ss.hasPermi('system:info:add')")
    @Log(title = "【摊位信息】", businessType = BusinessType.INSERT)
    @RequestMapping(value="/add")
    public AjaxResult add(TStallInfo tStallInfo)
    {
        if (tStallInfo == null){
            return  AjaxResult.error("参数不正确");
        }
        if (StringUtils.isEmpty(tStallInfo.getStallNumber())){
            return  AjaxResult.error("摊位号不能为空");
        }
        if (StringUtils.isEmpty(tStallInfo.getStallName())){
            return  AjaxResult.error("摊位名称不能为空");
        }
        if (StringUtils.isEmpty(tStallInfo.getMerchants())){
            return  AjaxResult.error("摊主姓名不能为空");
        }

        return toAjax(tStallInfoService.insertTStallInfo(tStallInfo));
    }

    /**
     * 修改【摊位信息】
     */
    @PreAuthorize("@ss.hasPermi('system:info:edit')")
    @Log(title = "【摊位信息】", businessType = BusinessType.UPDATE)
    @RequestMapping(value="/edit")
    public AjaxResult edit(TStallInfo tStallInfo)
    {
        if (tStallInfo == null){
            return  AjaxResult.error("参数不正确");
        }
        if (StringUtils.isEmpty(tStallInfo.getId())){
            return  AjaxResult.error("Id不能为空");
        }
        if (StringUtils.isEmpty(tStallInfo.getStallNumber())){
            return  AjaxResult.error("摊位号不能为空");
        }
        if (StringUtils.isEmpty(tStallInfo.getStallName())){
            return  AjaxResult.error("摊位名称不能为空");
        }
        if (StringUtils.isEmpty(tStallInfo.getMerchants())){
            return  AjaxResult.error("摊主姓名不能为空");
        }

        System.out.println("------------------begin --------------------------");
        System.out.println(tStallInfo.toString());
        return toAjax(tStallInfoService.updateTStallInfo(tStallInfo));
    }

    /**
     * 删除【摊位信息】
     */
    @PreAuthorize("@ss.hasPermi('system:info:remove')")
    @Log(title = "【摊位信息】", businessType = BusinessType.DELETE)
	@RequestMapping("/delete")
    public AjaxResult remove(String id)
    {
        return toAjax(tStallInfoService.deleteTStallInfoById(id));
    }
}
